---
title: 포인트 충전(환금성)서비스 이용 방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 포인트 충전(환금성)서비스 이용 방법
  description: >-
    포인트 충전(크레딧, 사이버머니 등) 형태의 서비스는 환금성(현금화 가능한) 서비스로 분류됩니다. PG사 및 카드사 심사가 까다로울 수
    있으며, 포트원이 제공하는 심사 적용 기준을 참고하시기 바랍니다.
  keywords:
    - 서비스 이용방법
tags:
  - 공통
  - 결제대행사 계약
searchTags:
  - 사이버머니
  - 크레딧
  - 포인트충전
  - 환금성
  - 포인트
  - 충전서비스
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="'포인트 충전(크레딧, 사이버머니 등)’ 형태의 서비스는 ‘환금성(현금화 가능한)’ 서비스로 분류되어 
PG사 및 카드사 심사가 까다로울 수 있습니다." title="" />

<Callout content="결제 가능한 금액 한도(카드사별 상이, 결제시도하는 고객 카드번호별 '1일 30만 원' 등 제한)나 고객이 결제 진행 시, 인증수단 강화 등 결제대행사 및 카드사 입점이 제한적일 수 있습니다.
때문에 서비스 이용료 형태로 BM을 검토하시어 이용하시는 것으로 PG사에서 권고하고 있습니다.
***정확한 입점 가능 여부는 결제대행사에 가입신청하시어 입점 상담을 받아보셔야 확인이 가능하오니 결제대행사 계약을 위한 서비스 기본 구성 앱 내 구현하신 후, 가입 신청하시어 해당 결제대행사별 계약 담당자와 입점 상담 후 조건이 맞는 PG사로 이용하시기 바랍니다.**
" icon="💡" title="참고사항" />

### **심사 적용 기준**

기본적으로 카드사의 심사 기준으로 적용되며, 상시 변경될 수 있습니다.

- PG사의 내부 규정에 따라 상이 할 수 있습니다.
- 포인트 충전 형태의 서비스는 ‘정기결제 방식’은 카드사 심사가 불가합니다. (카드사 정책)
- 포인트 충전 형태의 서비스는 결제(포인트 충전) 후 서비스 제공(소진) 하는 기간이 PG사별로 상이하니 아래 표를 참고해 주세요.
- 결제 요청 한도 제한 적용 기준 : 동일 사업장에서 동일 카드번호로 누적 거래 건수/금액 기준

<Callout title="결제대행사별 포인트 충전(환금성) 서비스 안내↗" content="" />
